#!/usr/bin/perl -w								#  1

# quick and dirty kludge to extract the m/z values
# and raw counts from the xml files. This will not
# work for XML files in general, only the ones here.				#  5

# (012605) modded to work for a generalized number of samples, given the 
# assumption that all XML files are formatted along the lines of the ones
# here (ie, that the primary change between files is the number of
# samples). 									# 10

# (013005) Modded such that, if folder RawSpectra does not exist, the 
# script will ask the user if they want to create it and, if so, will 
# go ahead and create the folder
										# 15
use strict;
use warnings;

my $xml_dir = "RawXML";      # hard-coded ... if your directories are named
my $txt_dir = "RawSpectra";  # something different, make the change here	# 20

chdir $xml_dir or die "cannot find $xml_dir directory\n";
my @files = glob("*.xml");   # loads all the xml files into an array
chdir "..";   # go back home
										# 25
foreach my $xml_file (@files){ # for each file in @files

    my $txt_file = $xml_file;
    $txt_file =~ s/.xml$/.txt/; # changes the name to *.txt
										# 30
    open MY_XML_FILE, "$xml_dir/$xml_file";
    my @lines = <MY_XML_FILE>; # loads the file into an array
    close MY_XML_FILE;

    my $j = 0;  # counter so that values get copied in right place		# 35
    my $n_entries = 0; # define n_entries

    foreach my $k (@lines) { # for each line, search to see if it includes
			     # "tofDataNumSamples".  If it does, parse out
			     # the number of samples.  Then continue 		# 40
			     # incrementing $j until the samples start
	if($k =~ /tofDataNumSamples/) {

            my @fields_test = split(/</,$k);
	    @fields_test = split(/>/,$fields_test[1]);				# 45

	    $n_entries = $fields_test[1];
        }
	elsif($k =~ /^\s*[0-9]+/) {
	    last;								# 50
	}   

        $j++;
    }
										# 55
    my $j2;  			# starting at the end of the first set of 
    $j2 = $j + $n_entries;	# data samples ...

    until($lines[$j2] =~ /^\s*[0-9]+/) {      # increment the new counter until
	$j2++;			              # it reaches the beginning of the	# 60
    }					      # next set of samples.


#    print "n_entries is $n_entries\n";    # debug statement
										# 65
# Given the number of entries (found above) and knowledge of the general
# format of these sorts of XML files, it maps all the values into their 
# appropriate arrays, in preparation for printing to the txt files.

    my @tofValues = @lines[$j..($j+$n_entries-1)];				# 70
    my @processedData = @lines[$j2..($j2+$n_entries-1)];

# For those of us who are simpleminded and don't realize that we need an
# empty directory named "RawSpectra" (or whatever $txt_dir has been set to) 
# ... if the script doesn't find said directory, it will ask if the user 	# 75
# wants that directory to be made.  If so, it creates the directory and 
# moves on; otherwise it kills the program.

    unless (chdir $txt_dir) {  # unless $txt_dir exists
	print "Directory $txt_dir does not exist.  Create directory?  ";	# 80

	if (<STDIN> =~ /^y/i) {
	    mkdir("$txt_dir",0777) || die "Cannot make directory $txt_dir: $!";
	}
	else {									# 85
	    die "Directory $txt_dir does not exist in present directory.";
	}
    }
    else {
	chdir "..";  # returns home						# 90

# Prints the information gained from the XML files into the new text file.

        open MY_TXT_FILE, ">$txt_dir/$txt_file";
        print MY_TXT_FILE "M/Z,Intensity\n";					# 95
        for(my $i = 0; $i < $n_entries; $i++){
	    my @mz = split /,/, $processedData[$i];
	    my $mz = $mz[0] + 0;  # cheating way to remove whitespace
	    my $shortTofValue = $tofValues[$i] + 0;
	    print MY_TXT_FILE "$mz,$shortTofValue\n";				#100
        }
        close MY_TXT_FILE;
    }
}										#104